/*
 * main.c
 *
 *  Created on: 2017/1/19
 *      Author: User
 */

#include <stdio.h>
#include <stdlib.h> // malloc, free
#include <string.h>
#include <unistd.h>  // usleep (unix standard?)
#include "alt_types.h"  // alt_u32
#include "sys/alt_alarm.h" // time tick function (alt_nticks(), alt_ticks_per_second())
#include "system.h"
#include "io.h"

// bit mask for write control
#define START_BIT_MASK		0x80000000
#define DUMMY_DATA_BIT_MASK	0x40000000

// bit mask for read status
#define DONE_BIT_MASK		0x00000001

void ADC_CAPTURE(alt_u32 controller_base, alt_u32 memory_base, int nSampleNum){
	alt_u32  Control, status;
	int is_done = 0, is_timeout = 0, i;
	alt_16 Value;
	alt_16 *mem_base = (alt_16 *)memory_base;
	alt_u32 Timeout;

	// start capture

	Control = nSampleNum;
	//Control |= DUMMY_DATA_BIT_MASK; for test only
	IOWR(controller_base, 0x00, Control);
	Control |= START_BIT_MASK;
	IOWR(controller_base, 0x00, Control); // rising edge to trigger
	printf("Start Capture...\r\n");

	// wait done
	Timeout = alt_nticks() + alt_ticks_per_second();
	while(!is_done && !is_timeout){
		status = IORD(controller_base,0x00);
		if (status & DONE_BIT_MASK)
			is_done = 1;
		else if (alt_nticks() > Timeout)
			is_timeout = 1;
	}
	printf("status=%xh\r\n", status);

	// dump adc data
	if (is_timeout){
		printf("Timeout\r\n");
	}else{
		for(i=0;i<nSampleNum;i++){
			if ((i < 10) || (i > (nSampleNum-10))){ // only printf first 10 & last 10 sample
				Value = *(mem_base+i);
				printf("ADC[%d] = %d(%xh)\r\n", i, Value, (alt_u16)Value);
			}
		}
	}
}



int main(void){
	const int nSampleNum = 50000;
	printf("ADC Demo\r\n");

	printf("ADC-A:\r\n");
	ADC_CAPTURE(TERASIC_AD9254_A_BASE, ONCHIP_MEMORY2_ADC_A_BASE, nSampleNum);

	printf("ADC-B:\r\n");
	ADC_CAPTURE(TERASIC_AD9254_B_BASE, ONCHIP_MEMORY2_ADC_B_BASE, nSampleNum);


	return 0;

}
